==> 1.0.tar.gz: pymt940/pymt940/unicredit.py <==
from .main import CsvToMt940, TypeId
from datetime import date

import pandas as pd
import re


class Unicredit(CsvToMt940):

    def __init__(self, filename, iban):
        super().__init__()
        self.filename = filename
        self.iban = iban
        self.info_df = pd.read_csv(filename, nrows=1, sep=';')
        self.trans_df = pd.read_csv('export.csv', skiprows=2, sep=';',
                                    keep_default_na=False)
        self.transactions = map(self._statm_transactions, self.trans_df.values)
        # iban = 'RO50BACX0000001138725000'
        # st_nr = randint(100000000, 199999999)

    def convert(self):

        with open('unicredit_mt940_{}.txt'.format(str(date.today()).replace('-', '')), 'w') as export:
            export.write(self._statm_header())
            for elem in self.transactions:
                export.write(elem)
            export.write(self._statm_footer())

    def _statm_header(self):
        self.o_bal = self.dig_it(self.info_df['Opening Balance'][0])
        if self.o_bal > 0:
            cd_mark = 'C'
        else:
            cd_mark = 'D'
        if re.search('.', self.info_df['Opening Balance'][0]):
            n = self.info_df['Opening Balance'][0].replace('.', '')
        else:
            n = self.info_df['Opening Balance'][0]
        tr_ref_nr = ':20:' + str(self.info_df['Account'][0]) + '\n'
        acc_id = ':25:' + self.iban + '\n'
        st_ref = ':28:' + str(self.st_nr) + '\n'
        in_op_balance = ':60F:' + cd_mark + self.st_date +\
            self.info_df['Currency'][0] + n + '\n'
        return tr_ref_nr + acc_id + st_ref + in_op_balance

    def _statm_transactions(self, elem):
        if self.dig_it(elem[1]) > 0:
            CD_mark = 'C'
        else:
            CD_mark = 'D'
        if re.search('-', elem[1]):
            elem[1] = elem[1].replace('-', '')
        if re.search('.', elem[1]):
            elem[1] = elem[1].replace('.', '')
        if re.search(TypeId.types, elem[14], flags=re.RegexFlag.IGNORECASE):
            trans_type = TypeId.COMMISION + 'OPH0001138725000'  # temp workarround for missing type on comm.
        else:
            trans_type = TypeId.TRANSFER
        tr = ':61:' + elem[3][-2:] + elem[3][3:-5] + elem[3][:2] + elem[3][3:-5] +\
            elem[3][:2] + CD_mark + elem[1] + trans_type + str(elem[-2]) +\
            elem[5] + '\n'
        inf = elem[14] + elem[16] + '\n'
        more_inf = ':86:' + '+31' + elem[9] + '\n' + '+32' + elem[10] + '+33/' +\
            str(elem[-7]) + '\n'
        return tr + inf + more_inf

    def _statm_footer(self):
        c_bal = self.dig_it(self.info_df['Closing Balance'][0])
        if c_bal > 0:
            cd_mark = 'C'
        else:
            cd_mark = 'D'
        if re.search('.', self.info_df['Closing Balance'][0]):
            n = self.info_df['Closing Balance'][0].replace('.', '')
        else:
            n = self.info_df['Closing Balance'][0]
        fin_op_balance = ':62F:' + cd_mark + self.st_date + self.info_df['Currency'][0] + n
        return fin_op_balance

==> 1.0.1.tar.gz: pymt940/pymt940/unicredit.py <==
from .main import CsvToMt940, TypeId
from datetime import date

import pandas as pd
import re


class Unicredit(CsvToMt940):

    def __init__(self, filename, iban):
        super().__init__()
        self.filename = filename
        self.iban = iban
        self.info_df = pd.read_csv(self.filename, nrows=1, sep=';')
        self.trans_df = pd.read_csv(self.filename, skiprows=2, sep=';',
                                    keep_default_na=False)
        self.transactions = map(self._statm_transactions, self.trans_df.values)
        # iban = 'RO50BACX0000001138725000'
        # st_nr = randint(100000000, 199999999)

    def convert(self):

        with open('unicredit_mt940_{}.txt'.format(str(date.today()).replace('-', '')), 'w') as export:
            export.write(self._statm_header())
            for elem in self.transactions:
                export.write(elem)
            export.write(self._statm_footer())

    def _statm_header(self):
        self.o_bal = self.dig_it(self.info_df['Opening Balance'][0])
        if self.o_bal > 0:
            cd_mark = 'C'
        else:
            cd_mark = 'D'
        if re.search('.', self.info_df['Opening Balance'][0]):
            n = self.info_df['Opening Balance'][0].replace('.', '')
        else:
            n = self.info_df['Opening Balance'][0]
        tr_ref_nr = ':20:' + str(self.info_df['Account'][0]) + '\n'
        acc_id = ':25:' + self.iban + '\n'
        st_ref = ':28:' + str(self.st_nr) + '\n'
        in_op_balance = ':60F:' + cd_mark + self.st_date +\
            self.info_df['Currency'][0] + n + '\n'
        return tr_ref_nr + acc_id + st_ref + in_op_balance

    def _statm_transactions(self, elem):
        if self.dig_it(elem[1]) > 0:
            CD_mark = 'C'
        else:
            CD_mark = 'D'
        if re.search('-', elem[1]):
            elem[1] = elem[1].replace('-', '')
        if re.search('.', elem[1]):
            elem[1] = elem[1].replace('.', '')
        if re.search(TypeId.types, elem[14], flags=re.RegexFlag.IGNORECASE):
            trans_type = TypeId.COMMISION + 'OPH0001138725000'  # temp workarround for missing type on comm.
        else:
            trans_type = TypeId.TRANSFER
        tr = ':61:' + elem[3][-2:] + elem[3][3:-5] + elem[3][:2] + elem[3][3:-5] +\
            elem[3][:2] + CD_mark + elem[1] + trans_type + str(elem[-2]) +\
            elem[5] + '\n'
        inf = elem[14] + elem[16] + '\n'
        more_inf = ':86:' + '+31' + elem[9] + '\n' + '+32' + elem[10] + '+33/' +\
            str(elem[-7]) + '\n'
        return tr + inf + more_inf

    def _statm_footer(self):
        c_bal = self.dig_it(self.info_df['Closing Balance'][0])
        if c_bal > 0:
            cd_mark = 'C'
        else:
            cd_mark = 'D'
        if re.search('.', self.info_df['Closing Balance'][0]):
            n = self.info_df['Closing Balance'][0].replace('.', '')
        else:
            n = self.info_df['Closing Balance'][0]
        fin_op_balance = ':62F:' + cd_mark + self.st_date + self.info_df['Currency'][0] + n
        return fin_op_balance
